@@ -1,10 +1,24 @@
 package DBIx::Class::Migration::Sandbox;
 
 use Moose::Role;
+use Log::Any;
+use Carp 'croak';
 
 has target_dir => (is=>'ro', required=>1);
 has schema_class => (is=>'ro', required=>1);
 
+sub log_die {
+  my ($self, $msg) = @_;
+  $self->log->error($msg);
+  croak $msg;
+}
+
+has log => (
+    is  => 'ro',
+    isa => 'Log::Any::Proxy',
+    default => sub { Log::Any->get_logger( category => 'DBIx::Class::Migration') },
+);
+
 requires 'make_sandbox';
 
 1;
